@@ -104,7 +104,6 @@ class Serve( Singleton ):
                         sys.exit( status )
                 except KeyboardInterrupt :
                     sys.exit(0)
-                    
 
     def pollthread( self, args, server ):
         """Thread (daemon) to monitor for changing files."""
@@ -193,8 +192,13 @@ class Serve( Singleton ):
         # finally blocks, flush open files, etc.  In otherwords, it is rude.
         os._exit(3)
 
-    _watch_flag = fcntl.DN_MODIFY | fcntl.DN_CREATE | fcntl.DN_MULTISHOT
     def _watch_files( self, args ):
+        if 'darwin' in sys.platform :
+            log.info("Not supported on `darwin`")
+            os.exit(64)
+        else :
+            _watch_flag = fcntl.DN_MODIFY | fcntl.DN_CREATE | fcntl.DN_MULTISHOT
+
         filenames = [args.config] if args.config else []
         filenames.extend(
             getattr( mod, '__file__', None) for mod in sys.modules.values()
