@@ -8,44 +8,23 @@
 import hmac, hashlib, base64, re, calendar, email, time
 from   http.cookies import CookieError, SimpleCookie
 
-from   pluggdapps.plugin            import implements, Plugin
-from   pluggdapps.web.webinterfaces import IHTTPCookie
-import pluggdapps.utils             as h
+from   pluggdapps.plugin         import implements, Plugin
+from   pluggdapps.web.interfaces import IHTTPCookie
+import pluggdapps.utils          as h
 
 
-_default_settings = h.ConfigDict()
-_default_settings.__doc__ = \
-    "Configuration settings for HTTPCookie."
-
-_default_settings['secret']  = {
-    'default' : 'secure cookie signature',
-    'types'   : (str,),
-    'help'    : "Use this to sign the cookie value before sending it with the "
-                "response.",
-}
-_default_settings['value_encoding']  = {
-    'default' : 'latin1',
-    'types'   : (str,),
-    'help'    : "While computing signed cookie value, use this encoding before "
-                "return the value."
-}
-_default_settings['max_age_seconds']  = {
-    'default' : 3600 * 24 * 30,
-    'types'   : (int,),
-    'help'    : "Maximum age, in seconds, for a cookie to live after its "
-                "creation time. The default is 30 days.",
-}
-
 class HTTPCookie( Plugin ):
     """Cookie handling plugin. This plugin uses python standard library's
-    http.cookies module to process request and response cookies."""
+    http.cookies module to process request and response cookies. Refer to
+    :class:`pluggdapps.web.interfaces.IHTTPCookie` interface spec. to
+    understand the general intent and purpose this plugin."""
 
     implements( IHTTPCookie )
 
     #-- IHTTPCookie interface methods.
 
     def parse_cookies( self, headers ):
-        """:meth:`pluggdapps.web.webinterfaces.IHTTPCookie.parse_cookies` 
+        """:meth:`pluggdapps.web.interfaces.IHTTPCookie.parse_cookies` 
         interface method."""
         cookies = SimpleCookie()
         cookie = headers.get( 'cookie', '' )
@@ -57,7 +36,7 @@ class HTTPCookie( Plugin ):
             return None
 
     def set_cookie( self, cookies, name, value, **kwargs ) :
-        """:meth:`pluggdapps.web.webinterfaces.IHTTPCookie.set_cookie`
+        """:meth:`pluggdapps.web.interfaces.IHTTPCookie.set_cookie`
         interface method."""
         if re.search( r"[\x00-\x20]", name + value ):
             # Don't let us accidentally inject bad stuff
@@ -90,7 +69,7 @@ class HTTPCookie( Plugin ):
         return cookies
 
     def create_signed_value( self, name, value ):
-        """:meth:`pluggdapps.web.webinterfaces.IHTTPCookie.set_cookie`
+        """:meth:`pluggdapps.web.interfaces.IHTTPCookie.set_cookie`
         interface method."""
         parts = [ self['secret'], name, value, str( int( time.time() )) ]
         parts = [ x.encode( 'utf-8' ) for x in parts ]
@@ -100,7 +79,7 @@ class HTTPCookie( Plugin ):
         return signedval.decode( self['value_encoding'] )
 
     def decode_signed_value( self, name, signedval ):
-        """:meth:`pluggdapps.web.webinterfaces.IHTTPCookie.set_cookie`
+        """:meth:`pluggdapps.web.interfaces.IHTTPCookie.set_cookie`
         interface method."""
         if not signedval : return None
 
@@ -170,3 +149,25 @@ class HTTPCookie( Plugin ):
         sett['max_age_seconds'] = h.asint( sett['max_age_seconds'] )
         return sett
 
+_default_settings = h.ConfigDict()
+_default_settings.__doc__ = HTTPCookie.__doc__
+
+_default_settings['max_age_seconds']  = {
+    'default' : 3600 * 24 * 30,
+    'types'   : (int,),
+    'help'    : "Maximum age, in seconds, for a cookie to live after its "
+                "creation time. The default is 30 days.",
+}
+_default_settings['secret']  = {
+    'default'   : 'secure cookie signature',
+    'types'     : (str,),
+    'help'      : "Use this to sign the cookie value before sending it with "
+                  "the response.",
+    'webconfig' : False,
+}
+_default_settings['value_encoding']  = {
+    'default' : 'latin1',
+    'types'   : (str,),
+    'help'    : "While computing signed cookie value, use this encoding before "
+                "return the value."
+}
